# ConnectionCheck

A Connection Check object shows the results from a test of a connection’s parameters. This is a test performed by Stitch that checks the configuration of a source’s connection parameters. The nature of the test varies by connection type.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the connection check job. | [optional]
**mode** | **object** | This value will always be &#x60;check&#x60;. | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


